@@ -1,10 +1,7 @@
-from raylib.pyray import PyRay
+import pyray as pr
 from .common import find_file
 
 
-pr = PyRay()
-
-
 class Animation:
     def __init__(self, files, fps=25):
         self.files = files
